Search — Py4J

Py4J - A Bridge between Python and Java

### Navigation

- index
- modules |
- Home |
- Download |
- Doc |
- Blog |
- github |
- About »

# Search

Searching for multiple words only shows matches that contain all words.

### Questions/Feedback?

- Try the FAQ -- It answers many questions.
- Search for information in the archives of the py4j-users mailing list, or post a question.
- If you notice errors with this documentation, open a ticket and let us know. Please, only open a ticket for feedback or improvements on the docs. To get help, use the links above!

### Navigation

- index
- modules |
- Home |
- Download |
- Doc |
- Blog |
- github |
- About »